@@ -1,5 +1,5 @@
 /*
- * $Id: pgmodule.c 476 2013-01-02 22:51:34Z cito $
+ * $Id: pgmodule.c 492 2013-01-05 20:25:40Z cito $
  * PyGres, version 2.2 A Python interface for PostgreSQL database. Written by
  * D'Arcy J.M. Cain, (darcy@druid.net).  Based heavily on code written by
  * Pascal Andre, andre@chimay.via.ecp.fr. Copyright (c) 1995, Pascal Andre
@@ -119,6 +119,7 @@ int *get_type_array(PGresult *result, int nfields);
 
 static PyObject *decimal = NULL, /* decimal type */
 				*namedresult = NULL; /* function for getting named results */
+static char *decimal_point = "."; /* decimal point used in money values */
 
 
 /* --------------------------------------------------------------------- */
@@ -2154,27 +2155,29 @@ pgquery_getresult(pgqueryobject *self, PyObject *args)
 			else
 				switch (typ[j])
 				{
-					case 1:
+					case 1:  /* int2/4 */
 						val = PyInt_FromString(s, NULL, 10);
 						break;
 
-					case 2:
+					case 2:  /* int8 */
 						val = PyLong_FromString(s, NULL, 10);
 						break;
 
-					case 3:
+					case 3:  /* float/double */
 						tmp_obj = PyString_FromString(s);
 						val = PyFloat_FromString(tmp_obj, NULL);
 						Py_DECREF(tmp_obj);
 						break;
 
-					case 5:
+					case 5:  /* money */
 						for (k = 0;
 							 *s && k < sizeof(cashbuf) / sizeof(cashbuf[0]) - 1;
 							 s++)
 						{
-							if (isdigit(*s) || *s == '.')
+							if (isdigit(*s))
 								cashbuf[k++] = *s;
+							else if (*s == *decimal_point)
+								cashbuf[k++] = '.';
 							else if (*s == '(' || *s == '-')
 								cashbuf[k++] = '-';
 						}
@@ -2182,7 +2185,7 @@ pgquery_getresult(pgqueryobject *self, PyObject *args)
 						s = cashbuf;
 
 					/* FALLTHROUGH */ /* no break */
-					case 4:
+					case 4:  /* numeric */
 						if (decimal)
 						{
 							tmp_obj = Py_BuildValue("(s)", s);
@@ -2279,27 +2282,29 @@ pgquery_dictresult(pgqueryobject *self, PyObject *args)
 			else
 				switch (typ[j])
 				{
-					case 1:
+					case 1:  /* int2/4 */
 						val = PyInt_FromString(s, NULL, 10);
 						break;
 
-					case 2:
+					case 2:  /* int8 */
 						val = PyLong_FromString(s, NULL, 10);
 						break;
 
-					case 3:
+					case 3:  /* float/double */
 						tmp_obj = PyString_FromString(s);
 						val = PyFloat_FromString(tmp_obj, NULL);
 						Py_DECREF(tmp_obj);
 						break;
 
-					case 5:
+					case 5:  /* money */
 						for (k = 0;
 							 *s && k < sizeof(cashbuf) / sizeof(cashbuf[0]) - 1;
 							 s++)
 						{
-							if (isdigit(*s) || *s == '.')
+							if (isdigit(*s))
 								cashbuf[k++] = *s;
+							else if (*s == *decimal_point)
+								cashbuf[k++] = '.';
 							else if (*s == '(' || *s == '-')
 								cashbuf[k++] = '-';
 						}
@@ -2307,7 +2312,7 @@ pgquery_dictresult(pgqueryobject *self, PyObject *args)
 						s = cashbuf;
 
 					/* FALLTHROUGH */ /* no break */
-					case 4:
+					case 4:  /* numeric */
 						if (decimal)
 						{
 							tmp_obj = Py_BuildValue("(s)", s);
@@ -2421,14 +2426,11 @@ pg_getnotify(pgobject *self, PyObject *args)
 		PyObject   *notify_result,
 				   *temp;
 
-		if (!(notify_result = PyTuple_New(3)))
+		if (!(temp = PyString_FromString(notify->relname)))
 			return NULL;
 
-		if (!(temp = PyString_FromString(notify->relname)))
-		{
-			Py_DECREF(notify_result);
+		if (!(notify_result = PyTuple_New(3)))
 			return NULL;
-		}
 
 		PyTuple_SET_ITEM(notify_result, 0, temp);
 
@@ -3691,6 +3693,47 @@ static PyObject
 	return ret;
 }
 
+/* set decimal point */
+static char set_decimal_point__doc__[] =
+"set_decimal_point() -- set decimal point to be used for money values.";
+
+static PyObject *
+set_decimal_point(PyObject *self, PyObject * args)
+{
+	PyObject *ret = NULL;
+	char *s;
+
+	if (PyArg_ParseTuple(args, "s", &s))
+	{
+		decimal_point = s;
+		Py_INCREF(Py_None); ret = Py_None;
+	}
+	return ret;
+}
+
+/* get decimal point */
+static char get_decimal_point__doc__[] =
+"get_decimal_point() -- get decimal point to be used for money values.";
+
+static PyObject *
+get_decimal_point(PyObject *self, PyObject * args)
+{
+	PyObject *ret = NULL;
+
+	if (PyArg_ParseTuple(args, ""))
+	{
+		ret = PyString_FromString(decimal_point);
+	}
+	else
+	{
+		PyErr_SetString(PyExc_TypeError,
+			" get_decimal_point() takes no parameter");
+	}
+
+
+	return ret;
+}
+
 /* set decimal */
 static char set_decimal__doc__[] =
 "set_decimal(cls) -- set a decimal type to be used for numeric values.";
@@ -4093,6 +4136,10 @@ static struct PyMethodDef pg_methods[] = {
 			escape_bytea__doc__},
 	{"unescape_bytea", (PyCFunction) unescape_bytea, METH_VARARGS,
 			unescape_bytea__doc__},
+	{"set_decimal_point", (PyCFunction) set_decimal_point, METH_VARARGS,
+			set_decimal_point__doc__},
+	{"get_decimal_point", (PyCFunction) get_decimal_point, METH_VARARGS,
+			get_decimal_point__doc__},
 	{"set_decimal", (PyCFunction) set_decimal, METH_VARARGS,
 			set_decimal__doc__},
 	{"set_namedresult", (PyCFunction) set_namedresult, METH_VARARGS,
